@@ -31,7 +31,7 @@ class PendingLoggerLogsImpl : public KTp::PendingLoggerLogs
                                    const KTp::LogEntity &entity,
                                    const QDate &date,
                                    QObject *parent = 0);
-    virtual ~PendingLoggerLogsImpl();
+    ~PendingLoggerLogsImpl() override;
 
   private Q_SLOTS:
     void operationFinished(KTp::PendingLoggerOperation *op);
