@@ -34,7 +34,7 @@ public:
     };
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option,
-               const QModelIndex &index) const;
+               const QModelIndex &index) const override;
 
 };
 #endif // CHATLISTVIEWDELEGATE_H
